# translate.py -- Pamhyr
# Copyright (C) 2023  INRAE
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# -*- coding: utf-8 -*-

from PyQt5.QtCore import QCoreApplication

from View.Tools.PamhyrTranslate import PamhyrTranslate

from Model.LateralContribution.LateralContributionTypes import (
    NotDefined, LateralContrib, Rain, Evaporation,
)

_translate = QCoreApplication.translate

LC_types = {
    "ND": NotDefined,
    "LC": LateralContrib,
    "RA": Rain,
    "EV": Evaporation,
}

class LCTranslate(PamhyrTranslate):
    def __init__(self):
        super(LCTranslate, self).__init__()

        self._sub_dict["long_types"] = {
            "ND": _translate("LateralContribution", "Not defined"),
            "LC": _translate("LateralContribution", "Lateral contribution"),
            "RA": _translate("LateralContribution", "Rain"),
            "EV": _translate("LateralContribution", "Evaporation"),
        }

        self._sub_dict["table_headers"] = {
            "name": _translate("LateralContribution", "Name"),
            "type": _translate("LateralContribution", "Type"),
            "edge": _translate("LateralContribution", "Reach"),
            "begin_kp": _translate("LateralContribution", "Begin kp (m)"),
            "end_kp": _translate("LateralContribution", "End kp (m)")
        }
